pub struct HoprdConfig {
pub hopr: UserHoprLibConfig,
pub identity: Identity,
pub db: Db,
pub api: Api,
pub session_ip_forwarding: SessionIpForwardingConfig,
pub blokli_url: Option<String>,
pub strategy: StrategyConfig,
}Expand description
The main configuration object of the entire node.
The configuration is composed of individual configurations of corresponding component configuration objects.
An always up-to-date config YAML example can be found in example_cfg.yaml which is always in the root of this crate.
Fields
hopr: UserHoprLibConfigConfiguration related to hopr-lib functionality
identity: IdentityConfiguration regarding the identity of the node
db: DbConfiguration of the underlying database engine
api: ApiConfiguration relevant for the API of the node
session_ip_forwarding: SessionIpForwardingConfigConfiguration of the Session entry/exit node IP protocol forwarding.
blokli_url: Option<String>Blokli provider URL to connect to.
strategy: StrategyConfigConfiguration of underlying node behavior in the form strategies
Strategies represent automatically executable behavior performed by the node given pre-configured triggers.
Implementations
Sourceimpl HoprdConfig
impl HoprdConfig
pub fn as_redacted(&self) -> Self
pub fn as_redacted_string(&self) -> Result<String>